@@ -44,6 +44,8 @@ def post(user_id):
 
     data = request.get_json()
 
+    current_api.validate_user_schema(data)
+
     user = UserModel.get(id=user_id)
 
     password = data.get("password", None)
@@ -63,6 +65,7 @@ def post(user_id):
     if "ui_preferences" in data:
         user.ui_preferences = data["ui_preferences"]
 
+    current_api.on_user_update(user)
     current_api.database.session.commit()
 
     # personal data : user is current user, so always true
