@@ -62,6 +62,8 @@ def post(document_id):
     if document.is_redirection:
         raise BadRequest("The document is a redirection")
 
+    old_version = document.last_version
+
     body = request.get_json()
 
     comment = body["comment"]
@@ -71,10 +73,10 @@ def post(document_id):
 
     version_id = body["document"]["version_id"]
 
-    last_version = document.as_dict()
+    last_version_as_dict = document.as_dict()
 
-    if last_version["version_id"] != version_id:
-        raise EditConflict(last_version=last_version, your_version=body["document"])
+    if last_version_as_dict["version_id"] != version_id:
+        raise EditConflict(last_version=last_version_as_dict, your_version=body["document"])
 
     version = DocumentVersion(
         document=document,
@@ -92,7 +94,7 @@ def post(document_id):
 
     current_api.database.session.flush()
 
-    current_api.before_document_save(document)
+    current_api.on_document_save(document=document, old_version=old_version, new_version=version)
 
     current_api.database.session.commit()
 
